@@ -1,5 +1,5 @@
 // libTorrent - BitTorrent library
-// Copyright (C) 2005-2007, Jari Sundell
+// Copyright (C) 2005-2011, Jari Sundell
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -38,7 +38,7 @@
 #define LIBTORRENT_SOCKET_FILE_H
 
 #include <string>
-#include <inttypes.h>
+#include <cinttypes>
 #include <fcntl.h>
 #include <sys/types.h>
 
