@@ -1,39 +1,3 @@
-// libTorrent - BitTorrent library
-// Copyright (C) 2005-2011, Jari Sundell
-//
-// This program is free software; you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
-// (at your option) any later version.
-// 
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
-// 
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-//
-// In addition, as a special exception, the copyright holders give
-// permission to link the code of portions of this program with the
-// OpenSSL library under certain conditions as described in each
-// individual source file, and distribute linked combinations
-// including the two.
-//
-// You must obey the GNU General Public License in all respects for
-// all of the code used other than OpenSSL.  If you modify file(s)
-// with this exception, you may extend this exception to your version
-// of the file(s), but you are not obligated to do so.  If you do not
-// wish to do so, delete this exception statement from your version.
-// If you delete this exception statement from all source files in the
-// program, then also delete it here.
-//
-// Contact:  Jari Sundell <jaris@ifi.uio.no>
-//
-//           Skomakerveien 33
-//           3185 Skoppum, NORWAY
-
 #include "config.h"
 
 #include <stdio.h>
@@ -46,6 +10,7 @@
 #include "torrent/error.h"
 #include "torrent/poll.h"
 #include "torrent/throttle.h"
+#include "torrent/utils/log.h"
 #include "utils/diffie_hellman.h"
 
 #include "globals.h"
@@ -55,6 +20,10 @@
 #include "handshake.h"
 #include "handshake_manager.h"
 
+#define LT_LOG(log_fmt, ...)                                            \
+  lt_log_print(LOG_CONNECTION_HANDSHAKE, "handshake->%s: " log_fmt,     \
+               m_address.pretty_address_str().c_str(), __VA_ARGS__);
+
 namespace torrent {
 
 const char* Handshake::m_protocol = "BitTorrent protocol";
@@ -555,8 +524,7 @@ Handshake::read_peer() {
   manager->poll()->insert_write(this);
 
   // Give some extra time for reading/writing the bitfield.
-  priority_queue_erase(&taskScheduler, &m_taskTimeout);
-  priority_queue_insert(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(120)).round_seconds());
+  priority_queue_update(&taskScheduler, &m_taskTimeout, (cachedTime + rak::timer::from_seconds(120)).round_seconds());
 
   return true;
 }
@@ -862,7 +830,7 @@ restart:
     m_manager->receive_failed(this, e.type(), e.error());
 
   } catch (network_error& e) {
-    m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_error);
+    m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_read_error);
   }
 }
 
@@ -969,7 +937,7 @@ Handshake::event_write() {
     m_manager->receive_failed(this, e.type(), e.error());
 
   } catch (network_error& e) {
-    m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_error);
+    m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_write_error);
   }
 }
 
@@ -1070,7 +1038,7 @@ Handshake::prepare_peer_info() {
     m_peerInfo = m_download->peer_list()->connected(m_address.c_sockaddr(), PeerList::connect_incoming);
 
     if (m_peerInfo == NULL)
-      throw handshake_error(ConnectionManager::handshake_failed, e_handshake_network_error);
+      throw handshake_error(ConnectionManager::handshake_failed, e_handshake_no_peer_info);
 
     if (m_peerInfo->failed_counter() > m_manager->max_failed)
       throw handshake_error(ConnectionManager::handshake_dropped, e_handshake_toomanyfailed);
@@ -1221,7 +1189,7 @@ Handshake::event_error() {
   if (m_state == INACTIVE)
     throw internal_error("Handshake::event_error() called on an inactive handshake.");
 
-  m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_error);
+  m_manager->receive_failed(this, ConnectionManager::handshake_failed, e_handshake_network_socket_error);
 }
 
 }
