@@ -69,8 +69,7 @@ TrackerController::update_timeout(uint32_t seconds_to_next) {
   if (seconds_to_next != 0)
     next_timeout = (cachedTime + rak::timer::from_seconds(seconds_to_next)).round_seconds();
 
-  priority_queue_erase(&taskScheduler, &m_private->task_timeout);
-  priority_queue_insert(&taskScheduler, &m_private->task_timeout, next_timeout);
+  priority_queue_update(&taskScheduler, &m_private->task_timeout, next_timeout);
 }
 
 inline int
@@ -145,8 +144,7 @@ TrackerController::scrape_request(uint32_t seconds_to_request) {
   if (seconds_to_request != 0)
     next_timeout = (cachedTime + rak::timer::from_seconds(seconds_to_request)).round_seconds();
 
-  priority_queue_erase(&taskScheduler, &m_private->task_scrape);
-  priority_queue_insert(&taskScheduler, &m_private->task_scrape, next_timeout);
+  priority_queue_update(&taskScheduler, &m_private->task_scrape, next_timeout);
 }
 
 // The send_*_event() functions tries to ensure the relevant trackers
